@@ -3,9 +3,9 @@
 #' Map a set of languages and color them by feature or two sets of features.
 #'
 #' @param languages character vector of languages (can be written in lower case)
+#' @param features character vector of features
 #' @param latitude numeric vector of latitudes
 #' @param longitude numeric vector of longitudes
-#' @param features character vector of features
 #' @param stroke.features additional independent stroke features
 #' @param density.estimation additional independent features, used for density estimation
 #' @param popup character vector of strings that will appear in pop-up window
@@ -34,7 +34,8 @@
 #' @param label.hide logical. If FALSE, labels are displayed allways. If TRUE, labels are displayed on mouse over. By default is TRUE.
 #' @param label.position the position of labels: "left", "right", "top", "bottom"
 #' @param label.emphasize is the list. First argument is a vector of points in datframe that should be emphasized. Second argument is a string with a color for emphasis.
-#' @param legend logical. If TRUE, function show legend. By default is FALSE.
+#' @param label.only creates labels without markers
+#' @param legend logical. If TRUE, function show legend. By default is TRUE.
 #' @param legend.opacity a numeric vector of legend opacity.
 #' @param legend.position the position of the legend: "topright", "bottomright", "bottomleft","topleft"
 #' @param map.orientation a character verctor with values "Pacific" and "Atlantic". It distinguishes Pacific-centered and Atlantic-centered maps. By default is "Pacific".
@@ -61,9 +62,14 @@
 #' @param rectangle.lng vector of two longitude values for rectangle.
 #' @param rectangle.lat vector of two latitude values for rectangle.
 #' @param rectangle.color vector of rectangle border color.
-#' @param line.lng vector of two longitude values for line.
-#' @param line.lat vector of two latitude values for line.
+#' @param line.lng vector of two (or more) longitude values for line.
+#' @param line.lat vector of two (or more) latitude values for line.
+#' @param line.type a character string indicating which type of line is to be computed. One of "standard" (default), or "logit". The first one should be combined with the arguments line.lat and line.lng and provide simple lines. Other variant "logit" is the decision boundary of the logistic regression made using longitude and latitude coordinates (works only if feature argument have two levels).
 #' @param line.color vector of line color.
+#' @param line.label character vector that will appear near the line.
+#' @param line.opacity a numeric vector of line opacity.
+#' @param line.width a numeric vector of line width.
+#' @param graticule a numeric vector for graticule spacing in map units between horizontal and vertical lines.
 #' @param zoom.control logical. If TRUE, function shows zoom controls. By default is FALSE.
 #' @param zoom.level a numeric value of the zoom level.
 #' @author George Moroz <agricolamz@gmail.com>
@@ -110,8 +116,11 @@
 #' @importFrom leaflet addTiles
 #' @importFrom leaflet addProviderTiles
 #' @importFrom leaflet addPolygons
+#' @importFrom leaflet addSimpleGraticule
+#' @importFrom leaflet addPolylines
 #' @importFrom leaflet addCircleMarkers
 #' @importFrom leaflet addMarkers
+#' @importFrom leaflet addLabelOnlyMarkers
 #' @importFrom leaflet addLayersControl
 #' @importFrom leaflet addScaleBar
 #' @importFrom leaflet addLegend
@@ -121,6 +130,10 @@
 #' @importFrom leaflet layersControlOptions
 #' @importFrom leaflet icons
 #' @importFrom stats complete.cases
+#' @importFrom stats sd
+#' @importFrom stats glm
+#' @importFrom stats binomial
+#' @importFrom stats coef
 #' @importFrom grDevices gray
 #' @importFrom grDevices topo.colors
 #' @importFrom rowr cbind.fill
@@ -131,14 +144,15 @@
 
 map.feature <- function(languages,
                         features = "",
-                        popup = "",
                         label = "",
+                        popup = "",
                         latitude = NULL,
                         longitude = NULL,
                         label.hide = TRUE,
                         label.fsize = 14,
                         label.position = "right",
                         label.emphasize = list(NULL, "black"),
+                        label.only = FALSE,
                         stroke.features = NULL,
                         density.estimation = NULL,
                         density.estimation.color = NULL,
@@ -186,7 +200,12 @@ map.feature <- function(languages,
                         rectangle.color = "black",
                         line.lng = NULL,
                         line.lat = NULL,
+                        line.type = "standard",
                         line.color = "black",
+                        line.opacity = 0.8,
+                        line.label = NULL,
+                        line.width = 3,
+                        graticule = NULL,
                         minichart = NULL,
                         minichart.data = NULL,
                         minichart.time = NULL,
@@ -414,6 +433,58 @@ map.feature <- function(languages,
     )
   }
 
+  # map: add line ----------------------------------------------------------------
+  if(line.type == "standard"){
+    if (!is.null(line.lng) & !is.null(line.lat)) {
+      m <- m %>% leaflet::addPolylines(
+        lat = line.lat,
+        lng = line.lng,
+        color = line.color,
+        opacity = line.opacity,
+        label = line.label,
+        labelOptions = leaflet::labelOptions(
+          noHide = !(label.hide),
+          direction = label.position,
+          textOnly = TRUE,
+          style = list(
+            "font-size" = paste0(label.fsize, "px"),
+            "color" = label.emphasize[[2]]
+          )
+        ),
+        weight = line.width)
+    }
+  } else if(line.type == "logit"){
+    if(length(table(mapfeat.df$features)) == 2){
+      logit <- stats::glm(mapfeat.df$features~mapfeat.df$long+mapfeat.df$lat,
+                          family=stats::binomial)
+      slope <- stats::coef(logit)[2]/(-stats::coef(logit)[3])
+      intercept <- stats::coef(logit)[1]/(-stats::coef(logit)[3])
+      line.lat <- range(mapfeat.df$lat)+
+        c(-stats::sd(mapfeat.df$lat), stats::sd(mapfeat.df$lat))
+      line.lng <-  (line.lat - intercept)/slope
+      m <- m %>% leaflet::addPolylines(
+        lat = line.lat,
+        lng = line.lng,
+        color = line.color,
+        opacity = line.opacity,
+        label = line.label,
+        labelOptions = leaflet::labelOptions(
+          noHide = !(label.hide),
+          direction = label.position,
+          textOnly = TRUE,
+          style = list(
+            "font-size" = paste0(label.fsize, "px"),
+            "color" = label.emphasize[[2]]
+          )
+        ),
+        weight = line.width)
+    } else{
+      warning("If you want to plot the decision boundary of the logistic regression, the argument features should contain two levels.")
+    }
+  }
+
+
+
   # if there is density estimation ------------------------------------------
   if (!is.null(density.estimation)) {
     lapply(seq_along(my_poly), function(x) {
@@ -427,6 +498,11 @@ map.feature <- function(languages,
     })
   }
 
+  # map: add graticule ------------------------------------------------------
+  if (!is.null(graticule)) {
+    m <- m %>% leaflet::addSimpleGraticule(interval = graticule)
+  }
+
   # map: if there are stroke features ---------------------------------------
   if (!is.null(stroke.features)) {
     m <- m %>% leaflet::addCircleMarkers(
@@ -467,7 +543,7 @@ map.feature <- function(languages,
   }
 
   # map: add points ----------------------------------------
-  if (density.points != FALSE & is.null(minichart)) {
+  if (density.points != FALSE & is.null(minichart) & label.only == FALSE) {
     m <- m %>% leaflet::addCircleMarkers(
       lng = mapfeat.df$long,
       lat = mapfeat.df$lat,
@@ -534,48 +610,85 @@ map.feature <- function(languages,
 
   # map: labels -------------------------------------------------------------
 
-  if (density.points != FALSE & sum(label == "") != length(label)) {
-    m <- m %>% leaflet::addCircleMarkers(
-      lng = mapfeat.df$long,
-      lat = mapfeat.df$lat,
-      popup = mapfeat.df$link,
-      label = mapfeat.df$label,
-      labelOptions = leaflet::labelOptions(
-        noHide = !(label.hide),
-        direction = label.position,
-        textOnly = TRUE,
-        style = list("font-size" = paste0(label.fsize, "px"))
-      ),
-      stroke = FALSE,
-      radius = width * 3,
-      fillOpacity = 0,
-      color = "blue",
-      group = mapfeat.df$features
-    )
-    if ("emph" %in% colnames(mapfeat.df)) {
-      m <-
-        m %>% leaflet::addCircleMarkers(
-          lng = mapfeat.df[mapfeat.df$emph == "emph",]$long,
-          lat = mapfeat.df[mapfeat.df$emph == "emph",]$lat,
-          popup = mapfeat.df[mapfeat.df$emph == "emph",]$link,
-          label = mapfeat.df[mapfeat.df$emph == "emph",]$label,
+    if (label.only == FALSE) {
+      if (density.points != FALSE & sum(label == "") != length(label)) {
+        m <- m %>% leaflet::addCircleMarkers(
+          lng = mapfeat.df$long,
+          lat = mapfeat.df$lat,
+          popup = mapfeat.df$link,
+          label = mapfeat.df$label,
           labelOptions = leaflet::labelOptions(
             noHide = !(label.hide),
             direction = label.position,
             textOnly = TRUE,
-            style = list(
-              "font-size" = paste0(label.fsize, "px"),
-              "color" = label.emphasize[[2]]
-            )
+            style = list("font-size" = paste0(label.fsize, "px"))
           ),
           stroke = FALSE,
-          radius = 3 * width,
+          radius = width * 3,
           fillOpacity = 0,
-          color = "red",
+          color = pal(mapfeat.df$features),
           group = mapfeat.df$features
         )
+        if ("emph" %in% colnames(mapfeat.df)) {
+          m <-
+            m %>% leaflet::addCircleMarkers(
+              lng = mapfeat.df[mapfeat.df$emph == "emph", ]$long,
+              lat = mapfeat.df[mapfeat.df$emph == "emph", ]$lat,
+              popup = mapfeat.df[mapfeat.df$emph == "emph", ]$link,
+              label = mapfeat.df[mapfeat.df$emph == "emph", ]$label,
+              labelOptions = leaflet::labelOptions(
+                noHide = !(label.hide),
+                direction = label.position,
+                textOnly = TRUE,
+                style = list(
+                  "font-size" = paste0(label.fsize, "px"),
+                  "color" = label.emphasize[[2]]
+                )
+              ),
+              stroke = FALSE,
+              radius = 3 * width,
+              fillOpacity = 0,
+              color = "red",
+              group = mapfeat.df$features
+            )
+        }
+      }
+    } else{
+      if (density.points != FALSE & sum(label == "") != length(label)) {
+        m <- m %>% leaflet::addLabelOnlyMarkers(
+          lng = mapfeat.df$long,
+          lat = mapfeat.df$lat,
+          label = mapfeat.df$label,
+          labelOptions = leaflet::labelOptions(
+            noHide = TRUE,
+            direction = label.position,
+            textOnly = TRUE,
+            style = list("font-size" = paste0(label.fsize, "px"))
+          ),
+          group = mapfeat.df$features
+        )
+        if ("emph" %in% colnames(mapfeat.df)) {
+          m <-
+            m %>% leaflet::addLabelOnlyMarkers(
+              lng = mapfeat.df[mapfeat.df$emph == "emph", ]$long,
+              lat = mapfeat.df[mapfeat.df$emph == "emph", ]$lat,
+              popup = mapfeat.df[mapfeat.df$emph == "emph", ]$link,
+              label = mapfeat.df[mapfeat.df$emph == "emph", ]$label,
+              labelOptions = leaflet::labelOptions(
+                noHide = TRUE,
+                direction = label.position,
+                textOnly = TRUE,
+                style = list(
+                  "font-size" = paste0(label.fsize, "px"),
+                  "color" = label.emphasize[[2]]
+                )
+              ),
+              group = mapfeat.df$features
+            )
+        }
+      }
     }
-  }
+
 
   # map: images -------------------------------------------------------------
   if (!is.null(image.url)) {
@@ -687,17 +800,5 @@ map.feature <- function(languages,
       zoom = zoom.level
     )
   }
-
-  # add line ----------------------------------------------------------------
-  if (!is.null(line.lng) & !is.null(line.lat)) {
-    m <- m %>% leaflet::addPolylines(
-      lat = line.lat,
-      lng = line.lng,
-      color = line.color,
-      opacity = 1,
-      weight = 3
-    )
-  }
-
   m
 }
